Pinax Points
============

.. image:: http://slack.pinaxproject.com/badge.svg
   :target: http://slack.pinaxproject.com/

.. image:: https://img.shields.io/travis/pinax/pinax-points.svg
    :target: https://travis-ci.org/pinax/pinax-points

.. image:: https://img.shields.io/coveralls/pinax/pinax-points.svg
    :target: https://coveralls.io/r/pinax/pinax-points

.. image:: https://img.shields.io/pypi/dm/pinax-points.svg
    :target:  https://pypi.python.org/pypi/pinax-points/

.. image:: https://img.shields.io/pypi/v/pinax-points.svg
    :target:  https://pypi.python.org/pypi/pinax-points/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/pinax-points/
    
    
Pinax
------

Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps, themes, and starter project templates. 
This collection can be found at http://pinaxproject.com.

This app was developed as part of the Pinax ecosystem but is just a Django app and can be used independently of other Pinax apps.


pinax-points
-------------

``pinax-points`` is a points, positions and levels app for Django. 

``pinax-points``, formerly agon, provides the ability to track points on arbitrary
objects in your system.  The common case being ``User`` instances. It can
additionally keep track of positions for these objects to produce leaderboards.

This code has mostly been pulled out of `typewar`_ and made slightly more
generic to work well.

.. _typewar: http://typewar.com/


Running the Tests
------------------------------------

::

    $ pip install detox
    $ detox


Documentation
--------------

The Pinax documentation is available at http://pinaxproject.com/pinax/.


Code of Conduct
-----------------

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a code of conduct, which can be found here  http://pinaxproject.com/pinax/code_of_conduct/.


Pinax Project Blog and Twitter
--------------------------------

For updates and news regarding the Pinax Project, please follow us on Twitter at @pinaxproject and check out our blog http://blog.pinaxproject.com.









